/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM flockIMediaWebService.idl
 */

#ifndef __gen_flockIMediaWebService_h__
#define __gen_flockIMediaWebService_h__


#ifndef __gen_nsIDOMHTMLDocument_h__
#include "nsIDOMHTMLDocument.h"
#endif

#ifndef __gen_nsIWritablePropertyBag2_h__
#include "nsIWritablePropertyBag2.h"
#endif

#ifndef __gen_flockIWebService_h__
#include "flockIWebService.h"
#endif

#ifndef __gen_flockIListener_h__
#include "flockIListener.h"
#endif

#ifndef __gen_flockIPhotoUpload_h__
#include "flockIPhotoUpload.h"
#endif

#ifndef __gen_flockIMediaItem_h__
#include "flockIMediaItem.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    flockIPhotoAlbum */
#define FLOCKIPHOTOALBUM_IID_STR "cfcffc53-7c57-418c-ae84-f66ddd7b3f77"

#define FLOCKIPHOTOALBUM_IID \
  {0xcfcffc53, 0x7c57, 0x418c, \
    { 0xae, 0x84, 0xf6, 0x6d, 0xdd, 0x7b, 0x3f, 0x77 }}

class NS_NO_VTABLE NS_SCRIPTABLE flockIPhotoAlbum : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(FLOCKIPHOTOALBUM_IID)

  /* attribute AString id; */
  NS_SCRIPTABLE NS_IMETHOD GetId(nsAString & aId) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetId(const nsAString & aId) = 0;

  /* attribute AString title; */
  NS_SCRIPTABLE NS_IMETHOD GetTitle(nsAString & aTitle) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetTitle(const nsAString & aTitle) = 0;

  /* attribute AString url; */
  NS_SCRIPTABLE NS_IMETHOD GetUrl(nsAString & aUrl) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetUrl(const nsAString & aUrl) = 0;

  /* attribute boolean isPublic; */
  NS_SCRIPTABLE NS_IMETHOD GetIsPublic(PRBool *aIsPublic) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetIsPublic(PRBool aIsPublic) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(flockIPhotoAlbum, FLOCKIPHOTOALBUM_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_FLOCKIPHOTOALBUM \
  NS_SCRIPTABLE NS_IMETHOD GetId(nsAString & aId); \
  NS_SCRIPTABLE NS_IMETHOD SetId(const nsAString & aId); \
  NS_SCRIPTABLE NS_IMETHOD GetTitle(nsAString & aTitle); \
  NS_SCRIPTABLE NS_IMETHOD SetTitle(const nsAString & aTitle); \
  NS_SCRIPTABLE NS_IMETHOD GetUrl(nsAString & aUrl); \
  NS_SCRIPTABLE NS_IMETHOD SetUrl(const nsAString & aUrl); \
  NS_SCRIPTABLE NS_IMETHOD GetIsPublic(PRBool *aIsPublic); \
  NS_SCRIPTABLE NS_IMETHOD SetIsPublic(PRBool aIsPublic); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_FLOCKIPHOTOALBUM(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetId(nsAString & aId) { return _to GetId(aId); } \
  NS_SCRIPTABLE NS_IMETHOD SetId(const nsAString & aId) { return _to SetId(aId); } \
  NS_SCRIPTABLE NS_IMETHOD GetTitle(nsAString & aTitle) { return _to GetTitle(aTitle); } \
  NS_SCRIPTABLE NS_IMETHOD SetTitle(const nsAString & aTitle) { return _to SetTitle(aTitle); } \
  NS_SCRIPTABLE NS_IMETHOD GetUrl(nsAString & aUrl) { return _to GetUrl(aUrl); } \
  NS_SCRIPTABLE NS_IMETHOD SetUrl(const nsAString & aUrl) { return _to SetUrl(aUrl); } \
  NS_SCRIPTABLE NS_IMETHOD GetIsPublic(PRBool *aIsPublic) { return _to GetIsPublic(aIsPublic); } \
  NS_SCRIPTABLE NS_IMETHOD SetIsPublic(PRBool aIsPublic) { return _to SetIsPublic(aIsPublic); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_FLOCKIPHOTOALBUM(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetId(nsAString & aId) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetId(aId); } \
  NS_SCRIPTABLE NS_IMETHOD SetId(const nsAString & aId) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetId(aId); } \
  NS_SCRIPTABLE NS_IMETHOD GetTitle(nsAString & aTitle) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetTitle(aTitle); } \
  NS_SCRIPTABLE NS_IMETHOD SetTitle(const nsAString & aTitle) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetTitle(aTitle); } \
  NS_SCRIPTABLE NS_IMETHOD GetUrl(nsAString & aUrl) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetUrl(aUrl); } \
  NS_SCRIPTABLE NS_IMETHOD SetUrl(const nsAString & aUrl) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetUrl(aUrl); } \
  NS_SCRIPTABLE NS_IMETHOD GetIsPublic(PRBool *aIsPublic) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIsPublic(aIsPublic); } \
  NS_SCRIPTABLE NS_IMETHOD SetIsPublic(PRBool aIsPublic) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetIsPublic(aIsPublic); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public flockIPhotoAlbum
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_FLOCKIPHOTOALBUM

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, flockIPhotoAlbum)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* attribute AString id; */
NS_IMETHODIMP _MYCLASS_::GetId(nsAString & aId)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP _MYCLASS_::SetId(const nsAString & aId)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute AString title; */
NS_IMETHODIMP _MYCLASS_::GetTitle(nsAString & aTitle)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP _MYCLASS_::SetTitle(const nsAString & aTitle)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute AString url; */
NS_IMETHODIMP _MYCLASS_::GetUrl(nsAString & aUrl)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP _MYCLASS_::SetUrl(const nsAString & aUrl)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean isPublic; */
NS_IMETHODIMP _MYCLASS_::GetIsPublic(PRBool *aIsPublic)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP _MYCLASS_::SetIsPublic(PRBool aIsPublic)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    flockIMediaChannel */
#define FLOCKIMEDIACHANNEL_IID_STR "b208bef0-5658-11db-b0de-0800200c9a66"

#define FLOCKIMEDIACHANNEL_IID \
  {0xb208bef0, 0x5658, 0x11db, \
    { 0xb0, 0xde, 0x08, 0x00, 0x20, 0x0c, 0x9a, 0x66 }}

class NS_NO_VTABLE NS_SCRIPTABLE flockIMediaChannel : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(FLOCKIMEDIACHANNEL_IID)

  /* attribute AString id; */
  NS_SCRIPTABLE NS_IMETHOD GetId(nsAString & aId) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetId(const nsAString & aId) = 0;

  /* attribute boolean supportsSearch; */
  NS_SCRIPTABLE NS_IMETHOD GetSupportsSearch(PRBool *aSupportsSearch) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetSupportsSearch(PRBool aSupportsSearch) = 0;

  /* attribute AString title; */
  NS_SCRIPTABLE NS_IMETHOD GetTitle(nsAString & aTitle) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetTitle(const nsAString & aTitle) = 0;

  /* attribute nsISimpleEnumerator subChannels; */
  NS_SCRIPTABLE NS_IMETHOD GetSubChannels(nsISimpleEnumerator * *aSubChannels) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetSubChannels(nsISimpleEnumerator * aSubChannels) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(flockIMediaChannel, FLOCKIMEDIACHANNEL_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_FLOCKIMEDIACHANNEL \
  NS_SCRIPTABLE NS_IMETHOD GetId(nsAString & aId); \
  NS_SCRIPTABLE NS_IMETHOD SetId(const nsAString & aId); \
  NS_SCRIPTABLE NS_IMETHOD GetSupportsSearch(PRBool *aSupportsSearch); \
  NS_SCRIPTABLE NS_IMETHOD SetSupportsSearch(PRBool aSupportsSearch); \
  NS_SCRIPTABLE NS_IMETHOD GetTitle(nsAString & aTitle); \
  NS_SCRIPTABLE NS_IMETHOD SetTitle(const nsAString & aTitle); \
  NS_SCRIPTABLE NS_IMETHOD GetSubChannels(nsISimpleEnumerator * *aSubChannels); \
  NS_SCRIPTABLE NS_IMETHOD SetSubChannels(nsISimpleEnumerator * aSubChannels); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_FLOCKIMEDIACHANNEL(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetId(nsAString & aId) { return _to GetId(aId); } \
  NS_SCRIPTABLE NS_IMETHOD SetId(const nsAString & aId) { return _to SetId(aId); } \
  NS_SCRIPTABLE NS_IMETHOD GetSupportsSearch(PRBool *aSupportsSearch) { return _to GetSupportsSearch(aSupportsSearch); } \
  NS_SCRIPTABLE NS_IMETHOD SetSupportsSearch(PRBool aSupportsSearch) { return _to SetSupportsSearch(aSupportsSearch); } \
  NS_SCRIPTABLE NS_IMETHOD GetTitle(nsAString & aTitle) { return _to GetTitle(aTitle); } \
  NS_SCRIPTABLE NS_IMETHOD SetTitle(const nsAString & aTitle) { return _to SetTitle(aTitle); } \
  NS_SCRIPTABLE NS_IMETHOD GetSubChannels(nsISimpleEnumerator * *aSubChannels) { return _to GetSubChannels(aSubChannels); } \
  NS_SCRIPTABLE NS_IMETHOD SetSubChannels(nsISimpleEnumerator * aSubChannels) { return _to SetSubChannels(aSubChannels); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_FLOCKIMEDIACHANNEL(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetId(nsAString & aId) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetId(aId); } \
  NS_SCRIPTABLE NS_IMETHOD SetId(const nsAString & aId) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetId(aId); } \
  NS_SCRIPTABLE NS_IMETHOD GetSupportsSearch(PRBool *aSupportsSearch) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSupportsSearch(aSupportsSearch); } \
  NS_SCRIPTABLE NS_IMETHOD SetSupportsSearch(PRBool aSupportsSearch) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSupportsSearch(aSupportsSearch); } \
  NS_SCRIPTABLE NS_IMETHOD GetTitle(nsAString & aTitle) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetTitle(aTitle); } \
  NS_SCRIPTABLE NS_IMETHOD SetTitle(const nsAString & aTitle) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetTitle(aTitle); } \
  NS_SCRIPTABLE NS_IMETHOD GetSubChannels(nsISimpleEnumerator * *aSubChannels) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSubChannels(aSubChannels); } \
  NS_SCRIPTABLE NS_IMETHOD SetSubChannels(nsISimpleEnumerator * aSubChannels) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSubChannels(aSubChannels); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public flockIMediaChannel
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_FLOCKIMEDIACHANNEL

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, flockIMediaChannel)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* attribute AString id; */
NS_IMETHODIMP _MYCLASS_::GetId(nsAString & aId)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP _MYCLASS_::SetId(const nsAString & aId)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean supportsSearch; */
NS_IMETHODIMP _MYCLASS_::GetSupportsSearch(PRBool *aSupportsSearch)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP _MYCLASS_::SetSupportsSearch(PRBool aSupportsSearch)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute AString title; */
NS_IMETHODIMP _MYCLASS_::GetTitle(nsAString & aTitle)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP _MYCLASS_::SetTitle(const nsAString & aTitle)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsISimpleEnumerator subChannels; */
NS_IMETHODIMP _MYCLASS_::GetSubChannels(nsISimpleEnumerator * *aSubChannels)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP _MYCLASS_::SetSubChannels(nsISimpleEnumerator * aSubChannels)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    flockIMediaWebService */
#define FLOCKIMEDIAWEBSERVICE_IID_STR "c24095d7-1234-4e28-a642-20f4f657c8c8"

#define FLOCKIMEDIAWEBSERVICE_IID \
  {0xc24095d7, 0x1234, 0x4e28, \
    { 0xa6, 0x42, 0x20, 0xf4, 0xf6, 0x57, 0xc8, 0xc8 }}

class NS_NO_VTABLE NS_SCRIPTABLE flockIMediaWebService : public flockIWebService {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(FLOCKIMEDIAWEBSERVICE_IID)

  /**
 * Represents a web service that supports browsing of streams or collections of
 * rich media (eg. photos, video).
 *
 * More documentation here:
 * http://developer.flock.com/wiki/Accounts_Management
 *
 * @see flockIMediaAccount
 * @see flockIMediaUploadAccount
 */
/**
   * Adds to the document metadata indicating the presence (or not)
   * of media streams, in order to light up the media icon from the
   * URL bar.
   * @param aDocument (in) an HTML document to check
   * @param aAccount (in) the XPCOM account which has already been
   *        detected as logged in on this page.  If not provided, then no
   *        account was detected as being logged in for aDocument.
   */
  /* void decorateForMedia (in nsIDOMHTMLDocument aDocument, in flockIWebServiceAccount aAccount); */
  NS_SCRIPTABLE NS_IMETHOD DecorateForMedia(nsIDOMHTMLDocument *aDocument, flockIWebServiceAccount *aAccount) = 0;

  /* void findByUsername (in flockIListener aFlockListener, in AString aUsername); */
  NS_SCRIPTABLE NS_IMETHOD FindByUsername(flockIListener *aFlockListener, const nsAString & aUsername) = 0;

  /* void getAlbums (in flockIListener aFlockListener, in AString aUsername); */
  NS_SCRIPTABLE NS_IMETHOD GetAlbums(flockIListener *aFlockListener, const nsAString & aUsername) = 0;

  /**
   * Return the channel identified by AChannelId
   * @param AChannelId (in) the channel to return
   *
   * @return the media channel, or null if the channel doesn't exist
   */
  /* flockIMediaChannel getChannel (in AString AChannelId); */
  NS_SCRIPTABLE NS_IMETHOD GetChannel(const nsAString & AChannelId, flockIMediaChannel **_retval) = 0;

  /**
   * Enumerate through all channels
   *
   * @return a nsISimpleEnumerator of flockIMediaChannel
   */
  /* nsISimpleEnumerator enumerateChannels (); */
  NS_SCRIPTABLE NS_IMETHOD EnumerateChannels(nsISimpleEnumerator **_retval) = 0;

  /**
   * Return the formatter to display media item from this service
   *
   * @return a flockIMediaItemFormatter, or null if the default
   *         formatter should be used
   */
  /* flockIMediaItemFormatter getMediaItemFormatter (); */
  NS_SCRIPTABLE NS_IMETHOD GetMediaItemFormatter(flockIMediaItemFormatter **_retval) = 0;

  /* void migrateAccount (in AString aId, in AString aUsername); */
  NS_SCRIPTABLE NS_IMETHOD MigrateAccount(const nsAString & aId, const nsAString & aUsername) = 0;

  /**
   * Search service for photos.
   * @param aQuery (in) Specifies which media stream. Examples:
   *                    @li all
   *                    @li interestingness
   *                    @li user:44124365282@N01
   *                    @li user:44124365282@N01:sulfur
   *                    @li pool:35034354696@N01
   *
   *                    To specify that the stream should be filtered you
   *                    append ?mySearchTerm, like so:
   *                    @c user:44124365282@N01:sulfur?yosh
   *
   * @param aCount (in) The number of items you'd like to be returned.
   *                    Note that receiving this number is not guaranteed.
   *
   * @param aPage (in) Used in combination with aCount for pagination.
   *
   * @param aRequestId (in) Used to keep track of requests
   */
  /* void search (in flockIListener aFlockListener, in AString aQuery, in long aCount, in long aPage, in AString aRequestId); */
  NS_SCRIPTABLE NS_IMETHOD Search(flockIListener *aFlockListener, const nsAString & aQuery, PRInt32 aCount, PRInt32 aPage, const nsAString & aRequestId) = 0;

  /**
   * For a given query, return whether or not it supports search.
   *
   * @param aQuery (in) The query in question.
   */
  /* boolean supportsSearch (in AString aQuery); */
  NS_SCRIPTABLE NS_IMETHOD SupportsSearch(const nsAString & aQuery, PRBool *_retval) = 0;

  /**
   * For a given query, return the URL of the associated icon.
   * (Most services will just return the same icon for any query)
   *
   * @param aQuery (in)
   */
  /* AString getIconForQuery (in AString aQuery); */
  NS_SCRIPTABLE NS_IMETHOD GetIconForQuery(const nsAString & aQuery, nsAString & _retval) = 0;

  /**
   * Whether the service supports the concept of a user in the media bar.
   * This enables drill down into that user's media stream.
   */
  /* readonly attribute boolean supportsUsers; */
  NS_SCRIPTABLE NS_IMETHOD GetSupportsUsers(PRBool *aSupportsUsers) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(flockIMediaWebService, FLOCKIMEDIAWEBSERVICE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_FLOCKIMEDIAWEBSERVICE \
  NS_SCRIPTABLE NS_IMETHOD DecorateForMedia(nsIDOMHTMLDocument *aDocument, flockIWebServiceAccount *aAccount); \
  NS_SCRIPTABLE NS_IMETHOD FindByUsername(flockIListener *aFlockListener, const nsAString & aUsername); \
  NS_SCRIPTABLE NS_IMETHOD GetAlbums(flockIListener *aFlockListener, const nsAString & aUsername); \
  NS_SCRIPTABLE NS_IMETHOD GetChannel(const nsAString & AChannelId, flockIMediaChannel **_retval); \
  NS_SCRIPTABLE NS_IMETHOD EnumerateChannels(nsISimpleEnumerator **_retval); \
  NS_SCRIPTABLE NS_IMETHOD GetMediaItemFormatter(flockIMediaItemFormatter **_retval); \
  NS_SCRIPTABLE NS_IMETHOD MigrateAccount(const nsAString & aId, const nsAString & aUsername); \
  NS_SCRIPTABLE NS_IMETHOD Search(flockIListener *aFlockListener, const nsAString & aQuery, PRInt32 aCount, PRInt32 aPage, const nsAString & aRequestId); \
  NS_SCRIPTABLE NS_IMETHOD SupportsSearch(const nsAString & aQuery, PRBool *_retval); \
  NS_SCRIPTABLE NS_IMETHOD GetIconForQuery(const nsAString & aQuery, nsAString & _retval); \
  NS_SCRIPTABLE NS_IMETHOD GetSupportsUsers(PRBool *aSupportsUsers); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_FLOCKIMEDIAWEBSERVICE(_to) \
  NS_SCRIPTABLE NS_IMETHOD DecorateForMedia(nsIDOMHTMLDocument *aDocument, flockIWebServiceAccount *aAccount) { return _to DecorateForMedia(aDocument, aAccount); } \
  NS_SCRIPTABLE NS_IMETHOD FindByUsername(flockIListener *aFlockListener, const nsAString & aUsername) { return _to FindByUsername(aFlockListener, aUsername); } \
  NS_SCRIPTABLE NS_IMETHOD GetAlbums(flockIListener *aFlockListener, const nsAString & aUsername) { return _to GetAlbums(aFlockListener, aUsername); } \
  NS_SCRIPTABLE NS_IMETHOD GetChannel(const nsAString & AChannelId, flockIMediaChannel **_retval) { return _to GetChannel(AChannelId, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD EnumerateChannels(nsISimpleEnumerator **_retval) { return _to EnumerateChannels(_retval); } \
  NS_SCRIPTABLE NS_IMETHOD GetMediaItemFormatter(flockIMediaItemFormatter **_retval) { return _to GetMediaItemFormatter(_retval); } \
  NS_SCRIPTABLE NS_IMETHOD MigrateAccount(const nsAString & aId, const nsAString & aUsername) { return _to MigrateAccount(aId, aUsername); } \
  NS_SCRIPTABLE NS_IMETHOD Search(flockIListener *aFlockListener, const nsAString & aQuery, PRInt32 aCount, PRInt32 aPage, const nsAString & aRequestId) { return _to Search(aFlockListener, aQuery, aCount, aPage, aRequestId); } \
  NS_SCRIPTABLE NS_IMETHOD SupportsSearch(const nsAString & aQuery, PRBool *_retval) { return _to SupportsSearch(aQuery, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD GetIconForQuery(const nsAString & aQuery, nsAString & _retval) { return _to GetIconForQuery(aQuery, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD GetSupportsUsers(PRBool *aSupportsUsers) { return _to GetSupportsUsers(aSupportsUsers); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_FLOCKIMEDIAWEBSERVICE(_to) \
  NS_SCRIPTABLE NS_IMETHOD DecorateForMedia(nsIDOMHTMLDocument *aDocument, flockIWebServiceAccount *aAccount) { return !_to ? NS_ERROR_NULL_POINTER : _to->DecorateForMedia(aDocument, aAccount); } \
  NS_SCRIPTABLE NS_IMETHOD FindByUsername(flockIListener *aFlockListener, const nsAString & aUsername) { return !_to ? NS_ERROR_NULL_POINTER : _to->FindByUsername(aFlockListener, aUsername); } \
  NS_SCRIPTABLE NS_IMETHOD GetAlbums(flockIListener *aFlockListener, const nsAString & aUsername) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAlbums(aFlockListener, aUsername); } \
  NS_SCRIPTABLE NS_IMETHOD GetChannel(const nsAString & AChannelId, flockIMediaChannel **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetChannel(AChannelId, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD EnumerateChannels(nsISimpleEnumerator **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->EnumerateChannels(_retval); } \
  NS_SCRIPTABLE NS_IMETHOD GetMediaItemFormatter(flockIMediaItemFormatter **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMediaItemFormatter(_retval); } \
  NS_SCRIPTABLE NS_IMETHOD MigrateAccount(const nsAString & aId, const nsAString & aUsername) { return !_to ? NS_ERROR_NULL_POINTER : _to->MigrateAccount(aId, aUsername); } \
  NS_SCRIPTABLE NS_IMETHOD Search(flockIListener *aFlockListener, const nsAString & aQuery, PRInt32 aCount, PRInt32 aPage, const nsAString & aRequestId) { return !_to ? NS_ERROR_NULL_POINTER : _to->Search(aFlockListener, aQuery, aCount, aPage, aRequestId); } \
  NS_SCRIPTABLE NS_IMETHOD SupportsSearch(const nsAString & aQuery, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->SupportsSearch(aQuery, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD GetIconForQuery(const nsAString & aQuery, nsAString & _retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIconForQuery(aQuery, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD GetSupportsUsers(PRBool *aSupportsUsers) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSupportsUsers(aSupportsUsers); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public flockIMediaWebService
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_FLOCKIMEDIAWEBSERVICE

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, flockIMediaWebService)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* void decorateForMedia (in nsIDOMHTMLDocument aDocument, in flockIWebServiceAccount aAccount); */
NS_IMETHODIMP _MYCLASS_::DecorateForMedia(nsIDOMHTMLDocument *aDocument, flockIWebServiceAccount *aAccount)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void findByUsername (in flockIListener aFlockListener, in AString aUsername); */
NS_IMETHODIMP _MYCLASS_::FindByUsername(flockIListener *aFlockListener, const nsAString & aUsername)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void getAlbums (in flockIListener aFlockListener, in AString aUsername); */
NS_IMETHODIMP _MYCLASS_::GetAlbums(flockIListener *aFlockListener, const nsAString & aUsername)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* flockIMediaChannel getChannel (in AString AChannelId); */
NS_IMETHODIMP _MYCLASS_::GetChannel(const nsAString & AChannelId, flockIMediaChannel **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsISimpleEnumerator enumerateChannels (); */
NS_IMETHODIMP _MYCLASS_::EnumerateChannels(nsISimpleEnumerator **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* flockIMediaItemFormatter getMediaItemFormatter (); */
NS_IMETHODIMP _MYCLASS_::GetMediaItemFormatter(flockIMediaItemFormatter **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void migrateAccount (in AString aId, in AString aUsername); */
NS_IMETHODIMP _MYCLASS_::MigrateAccount(const nsAString & aId, const nsAString & aUsername)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void search (in flockIListener aFlockListener, in AString aQuery, in long aCount, in long aPage, in AString aRequestId); */
NS_IMETHODIMP _MYCLASS_::Search(flockIListener *aFlockListener, const nsAString & aQuery, PRInt32 aCount, PRInt32 aPage, const nsAString & aRequestId)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean supportsSearch (in AString aQuery); */
NS_IMETHODIMP _MYCLASS_::SupportsSearch(const nsAString & aQuery, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* AString getIconForQuery (in AString aQuery); */
NS_IMETHODIMP _MYCLASS_::GetIconForQuery(const nsAString & aQuery, nsAString & _retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean supportsUsers; */
NS_IMETHODIMP _MYCLASS_::GetSupportsUsers(PRBool *aSupportsUsers)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    flockIMediaAccount */
#define FLOCKIMEDIAACCOUNT_IID_STR "516ba5e4-ec91-4eae-b682-23c4132d94bf"

#define FLOCKIMEDIAACCOUNT_IID \
  {0x516ba5e4, 0xec91, 0x4eae, \
    { 0xb6, 0x82, 0x23, 0xc4, 0x13, 0x2d, 0x94, 0xbf }}

/**
 * Represents an account with a media web service.
 *
 * More documentation here:
 * http://developer.flock.com/wiki/Accounts_Management
 *
 * @see flockIMediaWebService
 */
class NS_NO_VTABLE NS_SCRIPTABLE flockIMediaAccount : public flockIWebServiceAccount {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(FLOCKIMEDIAACCOUNT_IID)

};

  NS_DEFINE_STATIC_IID_ACCESSOR(flockIMediaAccount, FLOCKIMEDIAACCOUNT_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_FLOCKIMEDIAACCOUNT \
  /* no methods! */

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_FLOCKIMEDIAACCOUNT(_to) \
  /* no methods! */

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_FLOCKIMEDIAACCOUNT(_to) \
  /* no methods! */

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public flockIMediaAccount
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_FLOCKIMEDIAACCOUNT

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, flockIMediaAccount)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* End of implementation class template. */
#endif


#endif /* __gen_flockIMediaWebService_h__ */
